import { TextField } from '@material-ui/core'
import Button from '@material-ui/core/Button'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { AccountEPGLData } from 'models'
import React, { useState } from 'react'
import EpglModalHint from './EpglModalHint'

export const StepIdentity = ({
  formData,
  setFormData,
}: {
  formData: AccountEPGLData
  setFormData: React.Dispatch<React.SetStateAction<AccountEPGLData>>
}) => {
  const { t } = useI18n()
  const [openHintModal, setOpenHintModal] = useState<boolean>(false)

  return (
    <div className="stepDetails stepIdentity">
      <h2 className="text-22-bold">{t('auth.eglgrandlyon.contractId')}</h2>
      <TextField
        label={t('auth.eglgrandlyon.contractIdTextField')}
        variant="outlined"
        type="number"
        id="contractId"
        value={formData.contractId}
        onChange={e => {
          if (e.target.value.length > 7) return
          setFormData(prev => ({ ...prev, contractId: e.target.value }))
        }}
        required
      />

      <h2 className="text-22-bold">{t('auth.eglgrandlyon.meteringId')}</h2>
      <TextField
        label={t('auth.eglgrandlyon.meteringIdTextField')}
        variant="outlined"
        type="text"
        id="meteringId"
        required
        value={formData.meteringId}
        onChange={e => {
          if (e.target.value.length > 11) return
          setFormData(prev => ({ ...prev, meteringId: e.target.value }))
        }}
      />

      <Button className="btnText" onClick={() => setOpenHintModal(true)}>
        {t('auth.eglgrandlyon.contractHints')}
      </Button>
      <EpglModalHint
        open={openHintModal}
        handleCloseClick={() => setOpenHintModal(false)}
      />
    </div>
  )
}
