import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { FluidType } from 'enums'
import { Dataload } from 'models'
import React from 'react'
import { formatNumberValues, getFluidName } from 'utils/utils'

interface DataloadSectionValueProps {
  dataload: Dataload
  fluidType: FluidType
}

const DataloadSectionValue = ({
  dataload,
  fluidType,
}: DataloadSectionValueProps) => {
  const { t } = useI18n()
  const FLUIDNAME = getFluidName(fluidType).toUpperCase()

  if (fluidType === FluidType.MULTIFLUID) {
    return (
      <>
        {formatNumberValues(dataload.value)}
        <div className="text-18-normal euroUnit">
          {t(`FLUID.${FLUIDNAME}.UNIT`)}
        </div>
      </>
    )
  }

  const formattedValue = formatNumberValues(dataload.value, FLUIDNAME, true)

  if (Number(formattedValue) >= 1000) {
    return (
      <>
        {formatNumberValues(dataload.value, FLUIDNAME)}
        <span className="text-18-normal">
          {t(`FLUID.${FLUIDNAME}.MEGAUNIT`)}
        </span>
      </>
    )
  }

  return (
    <>
      {formatNumberValues(dataload.value)}
      <span className="text-18-normal">{t(`FLUID.${FLUIDNAME}.UNIT`)}</span>
    </>
  )
}

export default DataloadSectionValue
