import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import challengeWon from 'assets/icons/visu/duelResult/challengeWon.svg'
import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import { formatNumberValues, importIconById } from 'utils/utils'
import './duelResultModal.scss'

interface DuelResultModalProps {
  open: boolean
  userChallenge: UserChallenge
  win: boolean
  handleCloseClick: () => void
}

const DuelResultModal = ({
  open,
  userChallenge,
  win,
  handleCloseClick,
}: DuelResultModalProps) => {
  const { t } = useI18n()
  const [resultIcon, setResultIcon] = useState<string>(defaultIcon)
  const result = formatNumberValues(
    Math.abs(userChallenge.duel.threshold - userChallenge.duel.userConsumption)
  )

  const statusKey = win ? 'success' : 'lost'

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(
        userChallenge.id + '-' + Number(win),
        'duelResult'
      )
      setResultIcon(icon || defaultIcon)
    }
    handleEcogestureIcon()
  }, [userChallenge, win])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('duel_result_modal.accessibility.window_title')}
      </div>
      <div className="duel-result-modal-root">
        <div className="imgResultContainer">
          {win && (
            <StyledIcon
              className="challengeWon"
              icon={challengeWon}
              size={300}
            />
          )}
          <StyledIcon className="imgResult" icon={resultIcon} size={180} />
        </div>
        <div className="text-28-normal title">
          {t(`duel_result_modal.${statusKey}.title`)}
        </div>
        <div className="text-18-bold">
          {t(`duel_result_modal.${statusKey}.message1`, { value: result })}
        </div>
        <div className="text-18-bold">
          {t(`duel_result_modal.${statusKey}.message2`, {
            title: userChallenge.title,
          })}
        </div>
        <Button
          aria-label={t('duel_result_modal.accessibility.button_validate')}
          className="btnSecondary"
          onClick={handleCloseClick}
        >
          {t(`duel_result_modal.${statusKey}.button_validate`)}
        </Button>
      </div>
    </Dialog>
  )
}

export default DuelResultModal
