import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import SingleEcogestureView from './SingleEcogestureView'

jest.mock(
  'components/Ecogesture/EfficiencyRating/EfficiencyRating',
  () => 'mock-EfficiencyRating'
)
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockGetEcogesturesByIds = jest.fn()
const mockUpdateEcogesture = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getEcogesturesByIds: mockGetEcogesturesByIds,
    updateEcogesture: mockUpdateEcogesture,
  }))
})

describe('SingleEcogesture component', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])
    const { container } = render(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
  })

  it('should be able to show more details and change status', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])
    const updatedEcogesture = { ...mockedEcogesturesData[0], objective: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)

    render(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitFor(async () => {
      await userEvent.click(screen.getByText('ecogesture.objective'))
    })
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })

  it('should change doing status', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])
    const updatedEcogesture = { ...mockedEcogesturesData[0], doing: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)

    render(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitFor(async () => {
      await userEvent.click(screen.getByText('ecogesture.doing'))
    })
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })

  it('should toggle more details', async () => {
    mockGetEcogesturesByIds.mockResolvedValue([mockedEcogesturesData[0]])
    render(
      <Provider store={store}>
        <SingleEcogestureView />
      </Provider>
    )
    await waitFor(async () => {
      await userEvent.click(screen.getByText('ecogesture_modal.show_more'))
    })
    expect(screen.getByText('ecogesture_modal.show_less')).toBeInTheDocument()
  })
})
