import { FormControlLabel, Radio } from '@material-ui/core'
import classNames from 'classnames'
import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { EcogestureStepForm } from 'enums'
import {
  ProfileEcogesture,
  ProfileEcogestureAnswer,
  ProfileEcogestureValues,
} from 'models'
import React, { useCallback, useState } from 'react'
import { useAppSelector } from 'store/hooks'
import './ecogestureFormSingleChoice.scss'
interface EcogestureFormSingleChoiceProps {
  step: EcogestureStepForm
  viewedStep: EcogestureStepForm
  currentProfileEcogesture: ProfileEcogesture
  answerType: ProfileEcogestureAnswer
  setNextStep: (_profileEcogesture: ProfileEcogesture) => void
  setPreviousStep: () => void
}

const EcogestureFormSingleChoice = ({
  step,
  viewedStep,
  currentProfileEcogesture,
  answerType,
  setNextStep,
  setPreviousStep,
}: EcogestureFormSingleChoiceProps) => {
  const { t } = useI18n()
  const { isProfileEcogestureCompleted } = useAppSelector(
    state => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<ProfileEcogestureValues>(
    isProfileEcogestureCompleted || step < viewedStep
      ? currentProfileEcogesture[answerType.attribute]
      : null
  )

  const handleNext = useCallback(() => {
    setNextStep({ ...currentProfileEcogesture, [answerType.attribute]: answer })
  }, [currentProfileEcogesture, setNextStep, answer, answerType.attribute])

  const stepLabel = EcogestureStepForm[step].toLowerCase()

  return (
    <div className="ecogesture-profile-container">
      <div className="profile-form-container ecogesture-form-single">
        <div className="profile-question-label">
          {t(`ecogesture_form.${stepLabel}.question`)}
        </div>
        {answerType.choices.map(value => {
          if (value === null) return null
          return (
            <FormControlLabel
              key={value.toString()}
              className={classNames({
                ['radio_short']: answerType.choices.length < 5,
                ['radio_long']: answerType.choices.length > 4,
                ['answer-checked']: answer === value,
              })}
              control={
                <Radio
                  value={value.toString()}
                  checked={answer === value ? true : false}
                  onChange={() => setAnswer(value)}
                />
              }
              label={t(`ecogesture_form.${stepLabel}.${value}`)}
            />
          )
        })}
      </div>
      <FormNavigation
        handlePrevious={setPreviousStep}
        handleNext={handleNext}
        disablePrevButton={step === EcogestureStepForm.HEATING_TYPE}
        disableNextButton={answer === null}
      />
    </div>
  )
}

export default EcogestureFormSingleChoice
