/* eslint-disable jsx-a11y/no-noninteractive-tabindex */
/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
import { Button, ButtonGroup } from '@material-ui/core'
import classNames from 'classnames'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { FluidType, TimeStep } from 'enums'
import React from 'react'
import DateChartService from 'services/dateChart.service'
import { setCurrentIndex, setCurrentTimeStep } from 'store/chart/chart.slice'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import './timeStepSelector.scss'

const TimeStepSelector = ({ fluidType }: { fluidType: FluidType }) => {
  const { t } = useI18n()
  const dispatch = useAppDispatch()
  const { currentTimeStep, selectedDate } = useAppSelector(
    state => state.ecolyo.chart
  )
  const dateChartService = new DateChartService()
  const timeStepMultiArray: TimeStep[] = [
    TimeStep.WEEK,
    TimeStep.DAY,
    TimeStep.MONTH,
    TimeStep.YEAR,
  ]
  const timeStepArray: TimeStep[] =
    fluidType === FluidType.ELECTRICITY
      ? [TimeStep.HALF_AN_HOUR, ...timeStepMultiArray]
      : [...timeStepMultiArray]

  const handleChangeTimeStep = (targetTimestep: TimeStep) => {
    const index = dateChartService.defineDateIndex(targetTimestep, selectedDate)
    dispatch(setCurrentTimeStep(targetTimestep))
    dispatch(setCurrentIndex(index))
  }
  return (
    <div className="timestep-selector">
      <ButtonGroup role="tablist">
        {timeStepArray.map(step => (
          <Button
            key={step}
            role="tab"
            onClick={() => handleChangeTimeStep(step)}
            className={classNames('btnTab', {
              active: step === currentTimeStep,
            })}
          >
            {t(`timestep.${TimeStep[step].toLowerCase()}.period`)}
          </Button>
        ))}
      </ButtonGroup>
    </div>
  )
}

export default TimeStepSelector
