import { FormControlLabel, Radio } from '@material-ui/core'
import classNames from 'classnames'
import FormNavigation from 'components/CommonKit/FormNavigation/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { ProfileTypeStepForm } from 'enums'
import {
  ProfileEcogesture,
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeValues,
} from 'models'
import React, { useCallback, useEffect, useState } from 'react'
import { useAppSelector } from 'store/hooks'

interface ProfileTypeFormSingleChoiceProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  currentProfileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType: ProfileType) => void
  setPreviousStep: () => void
}

const ProfileTypeFormSingleChoice = ({
  step,
  viewedStep,
  currentProfileType,
  answerType,
  setNextStep,
  setPreviousStep,
}: ProfileTypeFormSingleChoiceProps) => {
  const { t } = useI18n()
  const {
    profile: { isProfileTypeCompleted, isProfileEcogestureCompleted },
    profileEcogesture,
  } = useAppSelector(state => state.ecolyo)

  const [answer, setAnswer] = useState<ProfileTypeValues>('')

  const handleNext = useCallback(() => {
    setNextStep({ ...currentProfileType, [answerType.attribute]: answer })
  }, [currentProfileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    // Set answer if profileType is completed
    if (step < viewedStep || isProfileTypeCompleted) {
      setAnswer(currentProfileType[answerType.attribute])
      return
    }
    // Set answer if ecogestureProfile is completed
    if (isProfileEcogestureCompleted) {
      setAnswer(
        profileEcogesture[answerType.attribute as keyof ProfileEcogesture]
      )
    }
  }, [
    step,
    viewedStep,
    currentProfileType,
    answerType,
    isProfileTypeCompleted,
    isProfileEcogestureCompleted,
    profileEcogesture,
  ])

  const stepLabel = ProfileTypeStepForm[step].toLowerCase()

  return (
    <>
      <div className="profile-form-container">
        <div className="profile-question-label">
          {t(`profile_type.${stepLabel}.question`)}
        </div>
        {answerType.choices.map((value, index) => {
          if (value === null) return null
          return (
            <FormControlLabel
              key={index}
              className={classNames({
                ['radio_short']: answerType.choices.length < 5,
                ['radio_long']: answerType.choices.length > 4,
                ['answer-checked']: answer === value,
              })}
              control={
                <Radio
                  value={value.toString()}
                  checked={answer === value ? true : false}
                  onChange={() => setAnswer(value)}
                />
              }
              label={t(`profile_type.${stepLabel}.${value}`)}
            />
          )
        })}
      </div>
      <FormNavigation
        handlePrevious={setPreviousStep}
        handleNext={handleNext}
        disablePrevButton={step === ProfileTypeStepForm.HOUSING_TYPE}
        disableNextButton={answer === '' || answer === undefined}
      />
    </>
  )
}

export default ProfileTypeFormSingleChoice
