import ActionView from 'components/Action/ActionView'
import ChallengeView from 'components/Challenge/ChallengeView'
import { EpglConnectView } from 'components/Connection/EPGLConnect/EpglConnectView'
import { GrdfConnectView } from 'components/Connection/GRDFConnect/GrdfConnectView'
import SgeConnectView from 'components/Connection/SGEConnect/SgeConnectView'
import DuelView from 'components/Duel/DuelView'
import EcogestureFormView from 'components/EcogestureForm/EcogestureFormView'
import EcogestureSelectionView from 'components/EcogestureSelection/EcogestureSelectionView'
import ExplorationView from 'components/Exploration/ExplorationView'
import Loader from 'components/Loader/Loader'
import QuizView from 'components/Quiz/QuizView'
import TermsView from 'components/Terms/TermsView'
import { FluidType } from 'enums'
import { TermsStatus } from 'models'
import React, { lazy, Suspense } from 'react'
import { Navigate, Route, Routes } from 'react-router-dom'

const ConsumptionView = lazy(
  () => import('components/Consumption/ConsumptionView')
)
const EcogestureTabsView = lazy(
  () => import('components/Ecogesture/EcogestureTabsView')
)
const SingleEcogestureView = lazy(
  () => import('components/Ecogesture/SingleEcogestureView')
)
const OptionsView = lazy(() => import('components/Options/OptionsView'))
const LegalNoticeView = lazy(
  () => import('components/Options/LegalNotice/LegalNoticeView')
)
const GCUView = lazy(() => import('components/Options/GCU/GCUView'))
const AnalysisView = lazy(() => import('components/Analysis/AnalysisView'))
const ProfileTypeView = lazy(
  () => import('components/ProfileType/ProfileTypeView')
)

const AppRoutes = ({ termsStatus }: { termsStatus: TermsStatus }) => {
  return (
    <Suspense
      fallback={
        <div className="loaderContainer">
          <Loader />
        </div>
      }
    >
      <Routes>
        {!termsStatus.accepted && (
          <>
            <Route path="/terms" element={<TermsView />} />
            <Route path="*" element={<Navigate replace to="/terms" />} />
          </>
        )}
        {termsStatus.accepted && (
          <>
            <Route
              path="/consumption/electricity"
              element={<ConsumptionView fluidType={FluidType.ELECTRICITY} />}
            />
            <Route
              path="/consumption/water"
              element={<ConsumptionView fluidType={FluidType.WATER} />}
            />
            <Route
              path="/consumption/gas"
              element={<ConsumptionView fluidType={FluidType.GAS} />}
            />
            <Route
              path="/consumption"
              element={<ConsumptionView fluidType={FluidType.MULTIFLUID} />}
            />
            <Route path="/connect/electricity" element={<SgeConnectView />} />
            <Route path="/connect/water" element={<EpglConnectView />} />
            <Route path="/connect/gas" element={<GrdfConnectView />} />
            <Route path="/challenges/duel" element={<DuelView />} />
            <Route path="/challenges/quiz" element={<QuizView />} />
            <Route
              path="/challenges/exploration"
              element={<ExplorationView />}
            />
            <Route path="/challenges/action" element={<ActionView />} />
            <Route path="/challenges/" element={<ChallengeView />} />
            <Route path="/ecogesture-form" element={<EcogestureFormView />} />
            <Route
              path="/ecogesture-selection"
              element={<EcogestureSelectionView />}
            />
            <Route
              path="/ecogesture/:ecogestureID"
              element={<SingleEcogestureView />}
            />
            <Route path="/ecogestures" element={<EcogestureTabsView />} />
            <Route path="/options/legalnotice" element={<LegalNoticeView />} />
            <Route path="/options/gcu" element={<GCUView />} />
            <Route path="/options" element={<OptionsView />} />
            <Route path="/analysis" element={<AnalysisView />} />
            <Route path="/profiletype" element={<ProfileTypeView />} />
            <Route path="*" element={<Navigate replace to="/consumption" />} />
          </>
        )}
      </Routes>
    </Suspense>
  )
}

export default AppRoutes
