import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import logger from 'cozy-logger'
import {
  REMOTE_ORG_ECOLYO_AGENT_CUSTOM_POPUP,
  REMOTE_ORG_ECOLYO_AGENT_CUSTOM_POPUP_REC,
} from 'doctypes'
import { CustomPopup } from 'models'
import logApp from 'utils/logger'
import EnvironmentService from './environment.service'

const logStack = logger.namespace('customPopupService')

export default class CustomPopupService {
  private readonly _client: Client
  constructor(_client: Client) {
    this._client = _client
  }

  /**
   * Get information from backoffice about the status of custom popup
   * On success, respond the customPopup
   * Else, return undefined
   */
  public async getCustomPopup(): Promise<CustomPopup | undefined> {
    const env = new EnvironmentService()
    const remoteUrl = env.isProduction()
      ? REMOTE_ORG_ECOLYO_AGENT_CUSTOM_POPUP
      : REMOTE_ORG_ECOLYO_AGENT_CUSTOM_POPUP_REC
    try {
      logApp.info('[Initialization] Getting CustomPopup')
      const result: CustomPopup = await this._client
        .getStackClient()
        .fetchJSON('GET', remoteUrl)
      result.description = result.description.replace(/{cozyUrl}/g, './#/')
      return result
    } catch (error) {
      const errorMessage = `getCustomPopup: Failed to get custom popup:${JSON.stringify(
        error
      )}`
      logStack('error', errorMessage)
      logApp.error(errorMessage)
      Sentry.captureException(error)
    }
  }
}
