import DisconnectedOff from 'assets/icons/visu/disconnected-off.svg'
import DisconnectedOn from 'assets/icons/visu/disconnected-on.svg'
import ElecOff from 'assets/icons/visu/elec-off.svg'
import ElecOn from 'assets/icons/visu/elec-on.svg'
import GasOff from 'assets/icons/visu/gas-off.svg'
import GasOn from 'assets/icons/visu/gas-on.svg'
import MultiOff from 'assets/icons/visu/multi-off.svg'
import MultiOn from 'assets/icons/visu/multi-on.svg'
import WaterOff from 'assets/icons/visu/water-off.svg'
import WaterOn from 'assets/icons/visu/water-on.svg'
import { FluidType } from 'enums'
import { getActiveFluidIcon, getFluidIcon } from './picto'

const unknownFluidType = 99 as FluidType

describe('picto utils test', () => {
  describe('getFluidIcon test', () => {
    it('should return electricity icon', () => {
      const result = getFluidIcon(FluidType.ELECTRICITY)
      expect(result).toBe(ElecOn)
    })

    it('should return water icon', () => {
      const result = getFluidIcon(FluidType.WATER)
      expect(result).toBe(WaterOn)
    })

    it('should return Small gas icon', () => {
      const result = getFluidIcon(FluidType.GAS)
      expect(result).toBe(GasOn)
    })
    describe('case MULTI', () => {
      it('should return multifluid Icon', () => {
        const result = getFluidIcon(FluidType.MULTIFLUID)
        expect(result).toBe(MultiOn)
      })
    })
    it('should return default Icon', () => {
      const result = getFluidIcon(unknownFluidType)
      expect(result).toBe(DisconnectedOn)
    })
  })

  describe('getActiveFluidIcon test', () => {
    describe('case disconnected / disconnected', () => {
      it('should return disconnected icon', () => {
        const result = getActiveFluidIcon(FluidType.ELECTRICITY, false, false)
        expect(result).toBe(DisconnectedOff)
      })
      it('should return connected icon', () => {
        const result = getActiveFluidIcon(FluidType.ELECTRICITY, true, false)
        expect(result).toBe(DisconnectedOn)
      })
    })

    describe('fluid cases', () => {
      it('should return On icon for elec', () => {
        const result = getActiveFluidIcon(FluidType.ELECTRICITY, true, true)
        expect(result).toBe(ElecOn)
      })
      it('should return Off icon for elec', () => {
        const result = getActiveFluidIcon(FluidType.ELECTRICITY, false, true)
        expect(result).toBe(ElecOff)
      })
      it('should return On icon for gas', () => {
        const result = getActiveFluidIcon(FluidType.GAS, true, true)
        expect(result).toBe(GasOn)
      })
      it('should return Off icon for gas', () => {
        const result = getActiveFluidIcon(FluidType.GAS, false, true)
        expect(result).toBe(GasOff)
      })
      it('should return On icon for water', () => {
        const result = getActiveFluidIcon(FluidType.WATER, true, true)
        expect(result).toBe(WaterOn)
      })
      it('should return Off icon for water', () => {
        const result = getActiveFluidIcon(FluidType.WATER, false, true)
        expect(result).toBe(WaterOff)
      })
      it('should return On icon for multi', () => {
        const result = getActiveFluidIcon(FluidType.MULTIFLUID, true, true)
        expect(result).toBe(MultiOn)
      })
      it('should return Off icon for multi', () => {
        const result = getActiveFluidIcon(FluidType.MULTIFLUID, false, true)
        expect(result).toBe(MultiOff)
      })

      it('should test default case', () => {
        const result = getActiveFluidIcon(unknownFluidType, true, true)
        expect(result).toBe(ElecOn)
      })
    })
  })
})
